@@ -1,3 +1,4 @@
+import sys
 from Acquisition import aq_base
 from Acquisition import aq_chain
 from Acquisition import aq_inner
@@ -18,19 +19,22 @@ from plone.dexterity.interfaces import IDexterityFTI
 from plone.directives import dexterity
 from plone.directives import form
 from plone.app.dexterity.behaviors.metadata import IBasic
-from htmllaundry.z3cform import HtmlText
-from euphorie.content.fti import ConditionalDexterityFTI
-from euphorie.content.fti import IConstructionFilter
-from euphorie.content.behaviour.richdescription import IRichDescription
-from .. import MessageFactory as _
-from euphorie.content.utils import getTermTitleByValue
-from euphorie.content.utils import StripMarkup
-from euphorie.content.solution import ISolution
 from plone.namedfile import field as filefield
 from plonetheme.nuplone.skin.interfaces import NuPloneSkin
 from plonetheme.nuplone.z3cform.directives import depends
 from plonetheme.nuplone.z3cform.form import FieldWidgetFactory
 from plone.indexer import indexer
+from htmllaundry.z3cform import HtmlText
+from .fti import ConditionalDexterityFTI
+from .fti import IConstructionFilter
+from .fti import check_fti_paste_allowed
+from .behaviour.richdescription import IRichDescription
+from .behaviour.uniqueid import INameFromUniqueId
+from .behaviour.uniqueid import get_next_id
+from .utils import getTermTitleByValue
+from .utils import StripMarkup
+from .solution import ISolution
+from .. import MessageFactory as _
 
 grok.templatedir("templates")
 
@@ -118,10 +122,25 @@ class IRisk(form.Schema, IRichDescription, IBasic):
                     title=_("evalmethod_direct", default=u"Estimated")),
                 SimpleTerm(u"calculated",
                     title=_("evalmethod_calculated", default=u"Calculated")),
+                SimpleTerm(u"fixed",
+                    title=_("evalmethod_fixed", default=u"Skip evaluation")),
             ]),
             default=u"calculated",
             required=False)
 
+    depends("fixed_priority", "type", "==", "risk")
+    depends("fixed_priority", "evaluation_method", "==", "fixed")
+    fixed_priority = schema.Choice(
+            title=_("label_fixed_priority", default=u"priority"),
+            vocabulary=SimpleVocabulary([
+                SimpleTerm("low", title=_("priority_low", default=u"Low")),
+                SimpleTerm("medium",
+                    title=_("priority_medium", default=u"Medium")),
+                SimpleTerm("high", title=_("priority_high", default="High")),
+            ]),
+            required=False,
+            default="low")
+
     depends("default_priority", "type", "==", "risk")
     depends("default_priority", "evaluation_method", "==", "direct")
     default_priority = schema.Choice(
@@ -138,7 +157,7 @@ class IRisk(form.Schema, IRichDescription, IBasic):
                 SimpleTerm("high", title=_("priority_high", default="High")),
             ]),
             required=False,
-            default="none")
+            default="low")
 
     form.fieldset("main_image",
             label=_("header_main_image", default=u"Main image"),
@@ -240,7 +259,7 @@ class IFrenchEvaluation(form.Schema):
                 SimpleTerm(9, "regularly",
                     title=_("frequency_french_regularly",
                         default=u"Very often or regularly")),
-                ]),
+            ]),
             required=True,
             default=0)
 
@@ -317,6 +336,7 @@ class IKinneyRisk(IRisk, IKinneyEvaluation):
                         u"evaluated. For more details see the online "
                         u"manual."),
             fields=["type", "evaluation_method",
+                    "fixed_priority",
                     "default_priority",
                     "default_probability", "default_frequency",
                     "default_effect"])
@@ -330,9 +350,9 @@ class IFrenchRisk(IRisk, IFrenchEvaluation):
                         u"evaluated. For more details see the online "
                         u"manual."),
             fields=["type", "evaluation_method",
+                    "fixed_priority",
                     "default_priority",
-                    "default_severity", "default_frequency",
-                   ])
+                    "default_severity", "default_frequency"])
 
 
 class Risk(dexterity.Container):
@@ -354,6 +374,19 @@ class Risk(dexterity.Container):
     image4 = None
     caption4 = None
 
+    def _get_id(self, orig_id):
+        """Pick an id for pasted content."""
+        frame = sys._getframe(1)
+        ob = frame.f_locals.get('ob')
+        if ob is not None and INameFromUniqueId.providedBy(ob):
+            return get_next_id(self)
+        return super(Risk, self)._get_id(orig_id)
+
+    def _verifyObjectPaste(self, object, validate_src=True):
+        super(Risk, self)._verifyObjectPaste(object, validate_src)
+        if validate_src:
+            check_fti_paste_allowed(self, object)
+
     def evaluation_algorithm(self):
         """Return the evaluation algorithm used by this risk. The
         algorithm is determined by the `evaluation_algorithm` flag
@@ -361,6 +394,14 @@ class Risk(dexterity.Container):
         """
         return evaluation_algorithm(self)
 
+    @property
+    def fixed_priority(self):
+        return self.default_priority
+
+    @fixed_priority.setter
+    def fixed_priority(self, value):
+        self.default_priority = value
+
 
 def EnsureInterface(risk):
     """Make sure a risk has the correct interface set for, matching the
